@@ -84,6 +84,7 @@ typedef struct {
 	ExifCategory category;
 } ExifTagCategory;
 
+#ifdef HAVE_EXIF
 static ExifTagCategory exif_tag_category_map[] = {
 	{ EXIF_TAG_INTEROPERABILITY_INDEX,    EXIF_CATEGORY_CAMERA},
 	{ EXIF_TAG_INTEROPERABILITY_VERSION,  EXIF_CATEGORY_CAMERA},
@@ -190,6 +191,7 @@ static ExifTagCategory exif_tag_category_map[] = {
 	{ EXIF_TAG_IMAGE_UNIQUE_ID	, EXIF_CATEGORY_IMAGE_DATA},
 	{ -1, -1 }
 };
+#endif
 
 #define MODEL_COLUMN_ATTRIBUTE 0
 #define MODEL_COLUMN_VALUE     1
@@ -276,6 +278,7 @@ eog_exif_details_class_init (EogExifDetailsClass *klass)
 	g_type_class_add_private (object_class, sizeof (EogExifDetailsPrivate));
 }
 
+#ifdef HAVE_EXIF
 static ExifCategory
 get_exif_category (ExifEntry *entry)
 {
@@ -291,6 +294,7 @@ get_exif_category (ExifEntry *entry)
 
 	return cat;
 }
+#endif
 
 static char*
 set_row_data (GtkTreeStore *store, char *path, char *parent, const char *attribute, const char *value)
@@ -343,6 +347,7 @@ set_row_data (GtkTreeStore *store, char *path, char *parent, const char *attribu
 	return path;
 }
 
+#ifdef HAVE_EXIF
 static void 
 exif_entry_cb (ExifEntry *entry, gpointer data)
 {
@@ -369,7 +374,7 @@ exif_entry_cb (ExifEntry *entry, gpointer data)
 	} else {
 
 		ExifMnoteData *mnote = (entry->tag == EXIF_TAG_MAKER_NOTE ?
-			exif_data_get_mnote_data (entry->parent->parent) : 0);
+			exif_data_get_mnote_data (entry->parent->parent) : NULL);
 
 		if (mnote) {
 			// Supported MakerNote Found
@@ -406,15 +411,18 @@ exif_entry_cb (ExifEntry *entry, gpointer data)
 		}
 	}
 }
+#endif
 
+#ifdef HAVE_EXIF
 static void
 exif_content_cb (ExifContent *content, gpointer data)
 {
 	exif_content_foreach_entry (content, exif_entry_cb, data);
 }
+#endif
 
 GtkWidget *
-eog_exif_details_new ()
+eog_exif_details_new (void)
 {
 	GObject *object;
 
@@ -447,6 +455,7 @@ eog_exif_details_reset (EogExifDetails *exif_details)
 	}
 }
 
+#ifdef HAVE_EXIF
 void
 eog_exif_details_update (EogExifDetails *exif_details, ExifData *data)
 {
@@ -461,7 +470,7 @@ eog_exif_details_update (EogExifDetails *exif_details, ExifData *data)
 		exif_data_foreach_content (data, exif_content_cb, exif_details);
 	}
 }
-
+#endif /* HAVE_EXIF */
 
 #ifdef HAVE_EXEMPI
 typedef struct {
@@ -499,8 +508,8 @@ get_xmp_category (XmpStringPtr schema)
 }
 
 static void 
-xmp_entry_insert (EogExifDetails *view, XmpStringPtr xmp_schema, 
-									XmpStringPtr xmp_path, XmpStringPtr xmp_prop)
+xmp_entry_insert (EogExifDetails *view, XmpStringPtr xmp_schema,
+		  XmpStringPtr xmp_path, XmpStringPtr xmp_prop)
 {
 	GtkTreeStore *store;
 	EogExifDetailsPrivate *priv;
@@ -510,8 +519,8 @@ xmp_entry_insert (EogExifDetails *view, XmpStringPtr xmp_schema,
 	
 	priv = view->priv;
 
-	key = g_strdup_printf ("%s:%s", xmp_string_cstr (xmp_schema), 
-			       xmp_string_cstr(xmp_path));
+	key = g_strconcat (xmp_string_cstr (xmp_schema), ":", 
+			   xmp_string_cstr (xmp_path), NULL);
 	
 	store = GTK_TREE_STORE (gtk_tree_view_get_model (GTK_TREE_VIEW (view)));
 	
