@@ -43,6 +43,7 @@
 #include "eog-thumbnail.h"
 
 #include <unistd.h>
+#include <string.h>
 
 #include <glib.h>
 #include <glib-object.h>
@@ -50,7 +51,6 @@
 #include <gtk/gtk.h>
 #include <gdk-pixbuf/gdk-pixbuf.h>
 #include <gdk-pixbuf/gdk-pixbuf-io.h>
-#include <libgnomeui/gnome-thumbnail.h>
 
 #ifdef HAVE_EXIF
 #include <libexif/exif-data.h>
@@ -1514,15 +1514,12 @@ eog_image_save_by_info (EogImage *img, EogImageSaveInfo *source, GError **error)
 static gboolean
 eog_image_copy_file (EogImageSaveInfo *source, EogImageSaveInfo *target, GError **error)
 {
-	char *target_file_path;
 	gboolean result;
 	GError *ioerror;
 
 	g_return_val_if_fail (EOG_IS_IMAGE_SAVE_INFO (source), FALSE);
 	g_return_val_if_fail (EOG_IS_IMAGE_SAVE_INFO (target), FALSE);
 	
-	target_file_path = g_file_get_path (target->file);
-	
 	result = g_file_copy (source->file,
 			      target->file,
 			      (target->overwrite ? G_FILE_COPY_OVERWRITE : 0) |
@@ -1536,11 +1533,11 @@ eog_image_copy_file (EogImageSaveInfo *source, EogImageSaveInfo *target, GError
 		if (ioerror->code == G_IO_ERROR_EXISTS) {
 			g_set_error (error, EOG_IMAGE_ERROR,
 				     EOG_IMAGE_ERROR_FILE_EXISTS,
-				     ioerror->message);
+				     "%s", ioerror->message);
 		} else {
 		g_set_error (error, EOG_IMAGE_ERROR,
 			     EOG_IMAGE_ERROR_VFS, 
-			     ioerror->message);
+			     "%s", ioerror->message);
 		}
 		g_error_free (ioerror);
 	}
